# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.subject import Subject  # noqa: E501

class TestSubject(unittest.TestCase):
    """Subject unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Subject:
        """Test Subject
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Subject`
        """
        model = Subject()  # noqa: E501
        if include_optional:
            return Subject(
                name = '',
                auditory = '',
                teacher = '',
                lesson = schedule_service_client.models.lesson.Lesson(
                    topic = 56, 
                    lesson = 56, 
                    type = '', )
            )
        else:
            return Subject(
        )
        """

    def testSubject(self):
        """Test Subject"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
