# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.worksheet_settings import WorksheetSettings  # noqa: E501

class TestWorksheetSettings(unittest.TestCase):
    """WorksheetSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorksheetSettings:
        """Test WorksheetSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WorksheetSettings`
        """
        model = WorksheetSettings()  # noqa: E501
        if include_optional:
            return WorksheetSettings(
                day_range = ERROR_TO_EXAMPLE_VALUE,
                year_range = ERROR_TO_EXAMPLE_VALUE,
                days_in_week_column_number = None,
                platoon_column_number = None,
                subject_rows_number = None
            )
        else:
            return WorksheetSettings(
        )
        """

    def testWorksheetSettings(self):
        """Test WorksheetSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
