# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.week_schedule import WeekSchedule  # noqa: E501

class TestWeekSchedule(unittest.TestCase):
    """WeekSchedule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WeekSchedule:
        """Test WeekSchedule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WeekSchedule`
        """
        model = WeekSchedule()  # noqa: E501
        if include_optional:
            return WeekSchedule(
                var_date = '',
                datetime = '',
                year_range = None,
                subjects = [
                    schedule_service_client.models.subject.Subject(
                        name = '', 
                        auditory = '', 
                        teacher = '', 
                        lesson = schedule_service_client.models.lesson.Lesson(
                            topic = 56, 
                            lesson = 56, 
                            type = '', ), )
                    ],
                coordinates = None
            )
        else:
            return WeekSchedule(
                coordinates = None,
        )
        """

    def testWeekSchedule(self):
        """Test WeekSchedule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
