# coding: utf-8

"""
    RTU MIREA VUC Schedule

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from schedule_service_client.models.validation_error_loc_inner import ValidationErrorLocInner  # noqa: E501

class TestValidationErrorLocInner(unittest.TestCase):
    """ValidationErrorLocInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ValidationErrorLocInner:
        """Test ValidationErrorLocInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ValidationErrorLocInner`
        """
        model = ValidationErrorLocInner()  # noqa: E501
        if include_optional:
            return ValidationErrorLocInner(
            )
        else:
            return ValidationErrorLocInner(
        )
        """

    def testValidationErrorLocInner(self):
        """Test ValidationErrorLocInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
